@@ -9,7 +9,7 @@ from sphinx.util.i18n import format_date
 from sphinx.util.logging import getLogger
 
 
-__version__ = '0.2.0'
+__version__ = '0.2.1'
 
 
 logger = getLogger(__name__)
@@ -53,6 +53,9 @@ def _html_page_context(app, pagename, templatename, context, doctree):
     lufmt = app.config.html_last_updated_fmt
     if lufmt is None or 'sourcename' not in context:
         return
+    if 'singlehtml' in app.builder.name:
+        assert context['sourcename'] == ''
+        return
     sourcefile = Path(app.confdir, pagename + context['page_source_suffix'])
     dates = []
     try:
